/*
 *      listProducts.h
 *      
 *      Copyright 2008 Tuxgasy <tuxgasy@tuxfamily.org>
 *      
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

#ifndef DEF_LISTPRODUCTS
#define DEF_LISTPRODUCTS

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <libxml/tree.h>
#include <libxml/parser.h>
#include <libxml/xpath.h>
#include <glib.h>

enum {CATEGORY_NO_ERROR, CATEGORY_ERROR_MALLOC, CATEGORY_ERROR_NO_FOUND};

enum {PRODUCT_NO_ERROR, PRODUCT_ERROR_MALLOC, PRODUCT_ERROR_NO_FOUND};

enum {MAKE_COMPATIBLE_OK, MAKE_COMPATIBLE_NOK};

/* init list of products */
xmlDocPtr initListProducts(const gchar *filename);

/* check if list of product is compatible with version 0.5 */
gboolean checkCompatibilityListProducts(xmlDocPtr xmlDocListProducts, const gchar *filename);

gint makeListProductsCompatible(xmlDocPtr xmlDocListProducts, const gchar *filename);

gint getCategoryByPosition(xmlDocPtr xmlDocListProducts, gint positionCategory, gchar **pCategory, gchar **pRef);

gint getSubCategoryByPosition(xmlDocPtr xmlDocListProducts, gint positionCategory, gint positionSubCategory, gchar **pSubCategory, gchar **pRef);

gint getProductReferenceByPosition(xmlDocPtr xmlDocListProducts, gint positionCategory, gint positionSubCategory, gint positionProduct, gchar **pRef);

gint getProductNameByPosition(xmlDocPtr xmlDocListProducts, gint positionCategory, gint positionSubCategory, gint positionProduct, gchar **pProductName);

gint getProductPriceByPosition(xmlDocPtr xmlDocListProducts, gint positionCategory, gint positionSubCategory, gint positionProduct, gchar **pProductPrice);

gint getPositionCategoryByReference(xmlDocPtr xmlDocListProducts, gchar *pRef);

gint getPositionSubCategoryByReference(xmlDocPtr xmlDocListProducts, gint positionCategory, gchar *pRef);

gint getPositionProductByReference(xmlDocPtr xmlDocListProducts, gint positionCategory, gint positionSubCategory, gchar *pRef);

void addNewCategoryToListProducts(xmlDocPtr xmlDocListProducts, const gchar *pName);

void addNewSubCategoryToListProducts(xmlDocPtr xmlDocListProducts, gint positionCategory, const gchar *pName);

void addNewProductToListProducts(xmlDocPtr xmlDocListProducts, gint positionCategory, gint positionSubCategory, const gchar *pName, gchar *pPrice);

void removeCategoryFromListProducts(xmlDocPtr xmlDocListProducts, gchar *pRef);

void removeSubCategoryFromListProducts(xmlDocPtr xmlDocListProducts, gchar *pRefCategory, gchar *pRef);

void removeProductFromListProducts(xmlDocPtr xmlDocListProducts, gchar *pRefCategory, gchar *pRefSubCategory, gchar *pRef);

void modifyCategoryFromListProducts(xmlDocPtr xmlDocListProducts, gchar *pRef, const gchar *pNewName);

void ModifySubCategoryFromListProducts(xmlDocPtr xmlDocListProducts, gchar *pRefCategory, gchar *pRef, const gchar *pNewName);

void modifyProductFromListProducts(xmlDocPtr xmlDocListProducts, gchar *pRefCategory, gchar *pRefSubCategory, gchar *pRef, const gchar *pNewName, const gchar *pNewPrice);

void modifyProductNameFromListProducts(xmlDocPtr xmlDocListProducts, gint positionCategory, gint positionSubCategory, gint positionProduct, const gchar *pNewName);

void modifyProductPriceFromListProducts(xmlDocPtr xmlDocListProducts, gint positionCategory, gint positionSubCategory, gint positionProduct, const gchar *pNewPrice);

void freeListProducts(xmlDocPtr xmlDocListProducts);

#endif
